World

Struct World 

pub struct World { /* private fields */ }
A minimal ECS supporting entity and component insertion/removal, association, and single-type iteration.

Implementations

Source

impl World

pub fn new() -> Self

Create a new ECS instance.

pub fn insert_entity(&mut self) -> EntityKey

Insert a new entity and return the corresponding entity key.

pub fn remove_entity(&mut self, entity_key: EntityKey) -> Option<()>

Remove an entity with the corresponding entity key. If the entity corresponding to the entity key is not found, return an None. Otherwise, return an Some(()).

pub fn contains_entity(&self, entity_key: EntityKey) -> bool

Return entity with the corresponding entity key. If the entity corresponding to the entity key is not found, return an None. Otherwise, return an Some(()).

pub fn iter_entity(&self) -> impl Iterator<Item = EntityKey> + '_

Return an iterator over all entity keys.

pub fn insert_component<T>( &mut self, entity_key: EntityKey, component: T, ) -> Option<()>
where T: Component,

Insert a new component with the corresponding entity key and return the corresponding component key. If the entity corresponding to the entity key is not found, return an None. Otherwise, return an Some(CompKey).

pub fn remove_component<T>(&mut self, entity_key: EntityKey) -> Option<()>
where T: Component,

Remove a component with the corresponding component key and type, and return the component. If the component corresponding to the component key and type is not found, return an None. Otherwise, return an Some(()).

pub fn get_component<T>(&self, entity_key: EntityKey) -> Option<&T>
where T: Component,

Return a component with the corresponding component key and type. If the component corresponding to the component key and type is not found, return an None. Otherwise, return an Some(&T).

pub fn get_component_mut<T>(&mut self, entity_key: EntityKey) -> Option<&mut T>
where T: Component,

Return a mutable component with the corresponding component key and type. If the component corresponding to the component key and type is not found, return an None. Otherwise, return an Some(&mut T).

pub fn iter_component<T>(&self) -> impl Iterator<Item = &T>
where T: Component,

Return an iterator over all components of the corresponding type. If the component type is not found, return an None. Otherwise, return an Some(impl Iterator<Item = &T>).

pub fn iter_component_mut<T>(&mut self) -> impl Iterator<Item = &mut T>
where T: Component,

Return a mutable iterator over all components of the corresponding type. If the component type is not found, return an None. Otherwise, return an Some(impl Iterator<Item = &mut T>).